@@ -6,8 +6,11 @@ from src.test_python_project.functions import (
     string_upper,
     load_brep,
 )
+import os
+import pytest
 
-
+#@pytest.mark.skip(reason="Skipping this test for now because ...") 
+@pytest.mark.slow
 def test_sum():
     assert sum(1, 2) == 3
     assert sum(2, 2) == 4
@@ -34,4 +37,5 @@ def test_string_upper():
 
 
 def test_load_brep():
-    assert load_brep("cube.og_brep")
+    data_path = os.path.join(os.path.dirname(__file__),"data","cube.og_brep")
+    assert load_brep(data_path)
